@@ -1,9 +1,9 @@
 use strict;
 use warnings;
-package Task::Kensho::WebCrawling; # git description: v0.39-61-g25f7fcd
+package Task::Kensho::WebCrawling; # git description: v0.40-28-g39a06bd
 # ABSTRACT: A Glimpse at an Enlightened Perl: Web Crawling
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 __END__
 
@@ -17,7 +17,7 @@ Task::Kensho::WebCrawling - A Glimpse at an Enlightened Perl: Web Crawling
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -66,6 +66,8 @@ facilitates the ease and simplicity the distribution aims to achieve.
 
 =head1 RECOMMENDED MODULES
 
+=for stopwords WebSocket
+
 =head2 L<Task::Kensho::WebCrawling>: Web Crawling
 
 =head3 L<HTTP::Thin>
@@ -84,6 +86,10 @@ Simple procedural interface to LWP
 
 Full-featured Web client library for Perl
 
+=head3 L<Mojo::UserAgent>
+
+Non-blocking I/O HTTP and WebSocket user agent
+
 =head3 L<WWW::Mechanize>
 
 Handy web browsing in a Perl object
@@ -122,7 +128,7 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
+Bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
 There is also an irc channel available for users of this distribution, at
 L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
@@ -133,7 +139,7 @@ Chris Prather <chris@prather.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Olaf Alders Dan Book Rachel Kelly Shawn Sorichetti Rick Leir
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Dan Book Mohammad S Anwar Olaf Alders Rachel Kelly Shawn Sorichetti Rick Leir Tina Müller
 
 =over 4
 
@@ -151,6 +157,14 @@ Chris Nehren <apeiron@cpan.org>
 
 =item *
 
+Dan Book <grinnz@grinnz.com>
+
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
@@ -169,6 +183,10 @@ Shawn Sorichetti <shawn@coloredblocks.com>
 
 Rick Leir <rleir@leirtech.com>
 
+=item *
+
+Tina Müller <cpan2@tinita.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
